==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_entities/partsassociated_001/PartsAssociated.java <==

package net.datastream.schemas.mp_entities.partsassociated_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTASSOCIATEDID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.VMRSCODE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLOCATIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDCOMMENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LONGDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partassociatedid",
    "partassociatedcode",
    "entity",
    "partid",
    "partquantity",
    "partlocationcode",
    "partassociatedtype",
    "uomcode",
    "vmrscode",
    "partassociatedcomment",
    "partconditiontemplateconditioncode",
    "longdescription"
})
@XmlRootElement(name = "PartsAssociated")
public class PartsAssociated {

    @XmlElement(name = "PARTASSOCIATEDID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTASSOCIATEDID_Type partassociatedid;
    @XmlElement(name = "PARTASSOCIATEDCODE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String partassociatedcode;
    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "PARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY partquantity;
    @XmlElement(name = "PARTLOCATIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partlocationcode;
    @XmlElement(name = "PARTASSOCIATEDTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String partassociatedtype;
    @XmlElement(name = "UOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String uomcode;
    @XmlElement(name = "VMRSCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected VMRSCODE_Type vmrscode;
    @XmlElement(name = "PARTASSOCIATEDCOMMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partassociatedcomment;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "LONGDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String longdescription;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété partassociatedid.
     * 
     * @return
     *     possible object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public PARTASSOCIATEDID_Type getPARTASSOCIATEDID() {
        return partassociatedid;
    }

    /**
     * Définit la valeur de la propriété partassociatedid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public void setPARTASSOCIATEDID(PARTASSOCIATEDID_Type value) {
        this.partassociatedid = value;
    }

    /**
     * Obtient la valeur de la propriété partassociatedcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTASSOCIATEDCODE() {
        return partassociatedcode;
    }

    /**
     * Définit la valeur de la propriété partassociatedcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTASSOCIATEDCODE(String value) {
        this.partassociatedcode = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété partquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPARTQUANTITY() {
        return partquantity;
    }

    /**
     * Définit la valeur de la propriété partquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPARTQUANTITY(QUANTITY value) {
        this.partquantity = value;
    }

    /**
     * Obtient la valeur de la propriété partlocationcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTLOCATIONCODE() {
        return partlocationcode;
    }

    /**
     * Définit la valeur de la propriété partlocationcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTLOCATIONCODE(String value) {
        this.partlocationcode = value;
    }

    /**
     * Obtient la valeur de la propriété partassociatedtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTASSOCIATEDTYPE() {
        return partassociatedtype;
    }

    /**
     * Définit la valeur de la propriété partassociatedtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTASSOCIATEDTYPE(String value) {
        this.partassociatedtype = value;
    }

    /**
     * Obtient la valeur de la propriété uomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Définit la valeur de la propriété uomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Obtient la valeur de la propriété vmrscode.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public VMRSCODE_Type getVMRSCODE() {
        return vmrscode;
    }

    /**
     * Définit la valeur de la propriété vmrscode.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public void setVMRSCODE(VMRSCODE_Type value) {
        this.vmrscode = value;
    }

    /**
     * Obtient la valeur de la propriété partassociatedcomment.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTASSOCIATEDCOMMENT() {
        return partassociatedcomment;
    }

    /**
     * Définit la valeur de la propriété partassociatedcomment.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTASSOCIATEDCOMMENT(String value) {
        this.partassociatedcomment = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété longdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLONGDESCRIPTION() {
        return longdescription;
    }

    /**
     * Définit la valeur de la propriété longdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLONGDESCRIPTION(String value) {
        this.longdescription = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/partsassociated_001/PartsAssociated.java <==

package net.datastream.schemas.mp_entities.partsassociated_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTASSOCIATEDID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.VMRSCODE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLOCATIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTASSOCIATEDCOMMENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LONGDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partassociatedid",
    "partassociatedcode",
    "entity",
    "partid",
    "partquantity",
    "partlocationcode",
    "partassociatedtype",
    "uomcode",
    "vmrscode",
    "partassociatedcomment",
    "partconditiontemplateconditioncode",
    "longdescription"
})
@XmlRootElement(name = "PartsAssociated")
public class PartsAssociated {

    @XmlElement(name = "PARTASSOCIATEDID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTASSOCIATEDID_Type partassociatedid;
    @XmlElement(name = "PARTASSOCIATEDCODE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String partassociatedcode;
    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "PARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY partquantity;
    @XmlElement(name = "PARTLOCATIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partlocationcode;
    @XmlElement(name = "PARTASSOCIATEDTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String partassociatedtype;
    @XmlElement(name = "UOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String uomcode;
    @XmlElement(name = "VMRSCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected VMRSCODE_Type vmrscode;
    @XmlElement(name = "PARTASSOCIATEDCOMMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partassociatedcomment;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "LONGDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String longdescription;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the partassociatedid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public PARTASSOCIATEDID_Type getPARTASSOCIATEDID() {
        return partassociatedid;
    }

    /**
     * Sets the value of the partassociatedid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTASSOCIATEDID_Type }
     *     
     */
    public void setPARTASSOCIATEDID(PARTASSOCIATEDID_Type value) {
        this.partassociatedid = value;
    }

    /**
     * Gets the value of the partassociatedcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTASSOCIATEDCODE() {
        return partassociatedcode;
    }

    /**
     * Sets the value of the partassociatedcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTASSOCIATEDCODE(String value) {
        this.partassociatedcode = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the partquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPARTQUANTITY() {
        return partquantity;
    }

    /**
     * Sets the value of the partquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPARTQUANTITY(QUANTITY value) {
        this.partquantity = value;
    }

    /**
     * Gets the value of the partlocationcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTLOCATIONCODE() {
        return partlocationcode;
    }

    /**
     * Sets the value of the partlocationcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTLOCATIONCODE(String value) {
        this.partlocationcode = value;
    }

    /**
     * Gets the value of the partassociatedtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTASSOCIATEDTYPE() {
        return partassociatedtype;
    }

    /**
     * Sets the value of the partassociatedtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTASSOCIATEDTYPE(String value) {
        this.partassociatedtype = value;
    }

    /**
     * Gets the value of the uomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Sets the value of the uomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Gets the value of the vmrscode property.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public VMRSCODE_Type getVMRSCODE() {
        return vmrscode;
    }

    /**
     * Sets the value of the vmrscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public void setVMRSCODE(VMRSCODE_Type value) {
        this.vmrscode = value;
    }

    /**
     * Gets the value of the partassociatedcomment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTASSOCIATEDCOMMENT() {
        return partassociatedcomment;
    }

    /**
     * Sets the value of the partassociatedcomment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTASSOCIATEDCOMMENT(String value) {
        this.partassociatedcomment = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the longdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLONGDESCRIPTION() {
        return longdescription;
    }

    /**
     * Sets the value of the longdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLONGDESCRIPTION(String value) {
        this.longdescription = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
